# 📈 - crypto-connect

crypto-connect is a CLI tool to keep track of cryptocurrencies.

# Documentation

Visit out [Documentation Page](https://iamkhattar.github.io/crypto-connect/#/) to view detailed documentation for crypto-connect.

# Install

How to install it

# Usage

```bash
crypto-connect --help

crypto-connect is a CLI tool to keep track of cryptocurrencies.

Options:
--help                                  Show this message and exit.

Commands:
currencies                              A list of currencies supported by crypto-connect
cryptocurrencies                        A list of crypto currencies supported by crypto-connect
price <cryptocurrrency> <currency>      Current price of the <cryptocurrrency> relative to the <currency>
history <cryptocurrrency> <currency>    A graph visualising the change in the <cryptocurrency> price in the past 30 days

Examples:
crypto-connect currencies
crypto-connect cryptocurrencies
crypto-connect price bitcoin usd
crypto-connect history bitcoin usd

```

# Contributors

<a href="https://github.com/iamkhattar"><img src="https://avatars3.githubusercontent.com/u/56852615?s=400&u=656d6befdb16f2be60c9c1f80456509a9dde69c4&v=4" title="iamkhattar" width="80" height="80"></a> <a href="https://github.com/kalqallaf"><img src="https://avatars0.githubusercontent.com/u/34354484?s=460&u=afae2a1029190dadb9a61b4eb7444710a1b4ee3d&v=4" title="kalqallaf" width="80" height="80"></a> <a href="https://github.com/Saeedado"><img src="https://avatars2.githubusercontent.com/u/63965340?s=460&v=4" title="Saeedado" width="80" height="80"></a>

# License

[MIT](https://opensource.org/licenses/MIT)
